pub struct Language { /* private fields */ }Implementations
Sourceimpl Language
impl Language
pub fn id(&self) -> &str
pub fn architecture(&self) -> &ArchitectureDef
pub fn version(&self) -> &str
pub fn sla_file(&self) -> &Path
pub fn processor_spec(&self) -> &PSpec
pub fn compiler_specs(&self) -> &Map<String, CSpec>
pub fn from_xml<P: AsRef<Path>>( root: P, input: Node<'_, '_>, ) -> Result<Self, DeserialiseError>
Sourcepub fn from_xml_with<P: AsRef<Path>>(
root: P,
input: Node<'_, '_>,
ignore_errors: bool,
) -> Result<Self, DeserialiseError>
pub fn from_xml_with<P: AsRef<Path>>( root: P, input: Node<'_, '_>, ignore_errors: bool, ) -> Result<Self, DeserialiseError>
Build Language object from each
Parameters
root: the search directory for finding related files specified in the .ldef file input: the xml::Node object which have name language for language definiation ignore_errors: if ignore parsing errors